@@ -1,17 +1,19 @@
-/* Time-stamp: <2009-05-07 21:48:07 shinya> */
+/* Time-stamp: <2009/06/02 11:24:00 Shinya Abe> */
 
 #include <stdlib.h>
 #include "cue/cue.h"
 #include "../src/add.h"
 
-CU_DEF(test_add)
+void 
+test_add()
 {
   CU_ASSERT_INT_EQUAL(add(1, 2), 3);
   CU_ASSERT_INT_EQUAL(add(2, -3), -1);
 }
 
 /* Example assertions */
-CU_DEF(test_assertion)
+void
+test_assertion()
 {
   CU_PASS("pass");
   CU_ASSERT_TRUE(1);
@@ -29,12 +31,8 @@ CU_DEF(test_assertion)
 int
 main(int argc, char **argv)
 {
-  CU_SETUP();
-
-  CU_REGISTER("add", test_add);
-  CU_REGISTER("assertion", test_assertion);
-
-  CU_RUN();
+  CU_TEST_CASE(test_add);
+  CU_TEST_CASE(test_assertion);
 
   return EXIT_SUCCESS;
 }
